@@ -10,34 +10,32 @@ unfortunately isn't extensible, so we can:
   * Try to get Django to offer hooks into makemessages().
   * Monkey-patch.
 
-We are currently doing that last thing. It turns out there we are lucky
-for once: It's simply a matter of extending two regular expressions.
-Credit for the approach goes to:
-http://stackoverflow.com/questions/2090717/getting-translation-strings-for-jinja2-templates-integrated-with-django-1-x
+We are currently doing that last thing. In this case we override the templatize
+method.  Templatize takes a template, extracts the translatable strings (along
+with desired metadata), and generates a file that xgettext knows how to parse,
+e.g. a file with Python syntax.  We override this function to find
+Mustache-tagged strings if the file that we are templatizing is in one of the
+paths found by the active MUSTACHEJS_FINDERS.
 """
 
 import os
 import re
 import sys
 
-from django.core.management.commands.makemessages import Command as I18nCommand
-from django.core.management.base import BaseCommand, CommandError
-from django.utils.text import get_text_list
-from django.utils.translation import templatize as orig_templatize
+from django.core.management.commands.makemessages \
+    import Command as BaseI18nCommand
+from django.utils.translation \
+    import templatize as base_templatize
 
-from mustachejs.loading import find, preprocess, MustacheJSTemplateNotFound
+from mustachejs.loading import find, preprocess
 from mustachejs.preprocessors import I18nPreprocessor
 
-class Command (I18nCommand):
-    help = 'Adds the translatable strings from the js templates to the messages'
+
+class Command (BaseI18nCommand):
+    help = ('Adds the translatable strings from the js templates to the '
+            'messages')
 
     def handle_noargs(self, *args, **options):
-        # Monkey-patch django.utils.translation.templatize to use the
-        # mustachejs version when dealing with a file that is in a mustachejs
-        # finder directory.
-        import django.utils.translation
-        django.utils.translation.templatize = templatize
-
         return super(Command, self).handle_noargs(*args, **options)
 
 
@@ -65,8 +63,8 @@ def templatize(src, origin=None):
 
             # Build a string that looks like a Python file that's ready to be
             # translated.
-            translatable = '\n'.join(['_("""{0}""")'.format(escape(string)) for string in strings
-            ])
+            translatable = '\n'.join(['_("""{0}""")'.format(escape(string))
+                                      for string in strings])
 
             return translatable
 
@@ -74,3 +72,14 @@ def templatize(src, origin=None):
     # method.
     else:
         return orig_templatize(src, origin)
+
+
+# ============================================================================
+#
+# Monkey-patch django.utils.translation.templatize to use the mustachejs
+# version when dealing with a file that is in a mustachejs finder directory.
+# Patch it globally so that any other commands that also patch the function
+# will inherit this functionality.
+
+import django.utils.translation
+django.utils.translation.templatize = templatize
